#ifndef _unamemeter_h
#define _unamemeter_h

#include <string>
#include "uname.h"

Unameinfo getUnameinfo();


#endif // _unamemeter_h
